package com.ruoyi.tcZz.service;

import com.ruoyi.tcZz.domain.TcYqzs;

import java.util.List;

/**
 * 舆情走势图Service接口
 *
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcYqzsService {
    /**
     * 查询舆情走势图
     *
     * @param id 舆情走势图主键
     * @return 舆情走势图
     */
    public TcYqzs selectTcYqzsById(Long id);

    /**
     * 查询舆情走势图列表
     *
     * @param tcYqzs 舆情走势图
     * @return 舆情走势图集合
     */
    public List<TcYqzs> selectTcYqzsList(TcYqzs tcYqzs);

    /**
     * 新增舆情走势图
     *
     * @param tcYqzs 舆情走势图
     * @return 结果
     */
    public int insertTcYqzs(TcYqzs tcYqzs);

    /**
     * 修改舆情走势图
     *
     * @param tcYqzs 舆情走势图
     * @return 结果
     */
    public int updateTcYqzs(TcYqzs tcYqzs);

    /**
     * 批量删除舆情走势图
     *
     * @param ids 需要删除的舆情走势图主键集合
     * @return 结果
     */
    public int deleteTcYqzsByIds(Long[] ids);

    /**
     * 删除舆情走势图信息
     *
     * @param id 舆情走势图主键
     * @return 结果
     */
    public int deleteTcYqzsById(Long id);


    /**
     * 导入舆情走势图信息
     *
     * @return 结果
     */
    public String importUser(List<TcYqzs> tcYqzsList);


    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
